# python-xymon-client

[![Codacy Badge](https://api.codacy.com/project/badge/Grade/054a56e80f3a4ce1aa519f23752413c1)](https://app.codacy.com/app/Romain-Dartigues-org/python-xymon-client?utm_source=github.com&utm_medium=referral&utm_content=romain-dartigues/python-xymon-client&utm_campaign=Badge_Grade_Dashboard)
[![Documentation Status](https://readthedocs.org/projects/python-xymon-client/badge/?version=latest)](https://python-xymon-client.readthedocs.io/en/latest/?badge=latest)

A minimalist [Xymon](https://www.xymon.com/) client library in Python.

Documentation is in the docs/ directory or [online](http://python-xymon-client.readthedocs.io/en/latest/).

Alternatives:

* https://github.com/skurfer/python-xymon
